==> tsconfig-0.0.1.tgz: package/README.md <==
<div align="center">

[![LOGO][LOGO]][HOMEPAGE]

<br/>

![version][VERSION_BADGE]
![MIT License][LICENSE_BADGE]

</div>

## Installation

[![npm][INSTALLATION_NPM_BADGE]][INSTALLATION_NPM]
[![Yarn][INSTALLATION_YARN_BADGE]][INSTALLATION_YARN]
[![pnpm][INSTALLATION_PNPM_BADGE]][INSTALLATION_PNPM]
[![bun][INSTALLATION_BUN_BADGE]][INSTALLATION_BUN]
[![deno][INSTALLATION_DENO_BADGE]][INSTALLATION_DENO]

### npm :

```sh
$ npm install --save-dev @wonize/tsconfig typescript
```

### yarn :

```sh
$ yarn add --dev @wonize/tsconfig typescript
```

### pnpm :

```sh
$ pnpm add --save-dev @wonize/tsconfig typescript
```

### Bun :

```sh
$ bun add --dev @wonize/tsconfig
```

<!-- URL -->

[LOGO]: https://raw.githubusercontent.com/wonize/tsconfig/main/assets/logo.svg
[HOMEPAGE]: https://github.com/wonize/tsconfig
[INSTALLATION_NPM_BADGE]: https://img.shields.io/static/v1?style=for-the-badge&message=npm&color=CB3837&logo=npm&logoColor=FFFFFF&label=
[INSTALLATION_YARN_BADGE]: https://img.shields.io/static/v1?style=for-the-badge&message=Yarn&color=2C8EBB&logo=Yarn&logoColor=FFFFFF&label=
[INSTALLATION_PNPM_BADGE]: https://img.shields.io/static/v1?style=for-the-badge&message=pnpm&color=FF6C37&logo=pnpm&logoColor=FFFFFF&label=
[INSTALLATION_BUN_BADGE]: https://img.shields.io/static/v1?style=for-the-badge&message=bun&color=E2BD8C&logo=bun&logoColor=FFFFFF&label=
[INSTALLATION_DENO_BADGE]: https://img.shields.io/static/v1?style=for-the-badge&message=deno&color=323232&logo=deno&logoColor=FFFFFF&label=
[INSTALLATION_NPM]: #npm
[INSTALLATION_YARN]: #yarn
[INSTALLATION_PNPM]: #pnpm
[INSTALLATION_BUN]: #bun
[INSTALLATION_DENO]: https://deno.land/manual@v1.36.4/examples/manage_dependencies
[VERSION_BADGE]: https://img.shields.io/npm/v/@wonize/tsconfig?color=00273F&label=VERSION&style=flat-square
[LICENSE_BADGE]: https://img.shields.io/npm/l/@wonize/tsconfig?color=00273F&label=LICENSE&style=flat-square

==> tsconfig-0.0.3.tgz: package/README.md <==
<div align="center">

[![BANNER][BANNER]][HOMEPAGE]

<br/>

![version][VERSION_BADGE]
![MIT License][LICENSE_BADGE]

</div>

## Installation

[![npm][INSTALLATION_NPM_BADGE]][INSTALLATION_NPM]
[![Yarn][INSTALLATION_YARN_BADGE]][INSTALLATION_YARN]
[![pnpm][INSTALLATION_PNPM_BADGE]][INSTALLATION_PNPM]
[![bun][INSTALLATION_BUN_BADGE]][INSTALLATION_BUN]
[![deno][INSTALLATION_DENO_BADGE]][INSTALLATION_DENO]

### npm :

```sh
$ npm install --save-dev @wonize/tsconfig typescript
```

### yarn :

```sh
$ yarn add --dev @wonize/tsconfig typescript
```

### pnpm :

```sh
$ pnpm add --save-dev @wonize/tsconfig typescript
```

### Bun :

```sh
$ bun add --dev @wonize/tsconfig
```

<!-- URL -->

[BANNER]: https://raw.githubusercontent.com/wonize/foundation/main/tsconfig/assets/tsconfig.png
[HOMEPAGE]: https://github.com/wonize/foundation/tree/main/tsconfig
[INSTALLATION_NPM_BADGE]: https://img.shields.io/static/v1?style=for-the-badge&message=npm&color=CB3837&logo=npm&logoColor=FFFFFF&label=
[INSTALLATION_YARN_BADGE]: https://img.shields.io/static/v1?style=for-the-badge&message=Yarn&color=2C8EBB&logo=Yarn&logoColor=FFFFFF&label=
[INSTALLATION_PNPM_BADGE]: https://img.shields.io/static/v1?style=for-the-badge&message=pnpm&color=FF6C37&logo=pnpm&logoColor=FFFFFF&label=
[INSTALLATION_BUN_BADGE]: https://img.shields.io/static/v1?style=for-the-badge&message=bun&color=E2BD8C&logo=bun&logoColor=FFFFFF&label=
[INSTALLATION_DENO_BADGE]: https://img.shields.io/static/v1?style=for-the-badge&message=deno&color=323232&logo=deno&logoColor=FFFFFF&label=
[INSTALLATION_NPM]: #npm-
[INSTALLATION_YARN]: #yarn-
[INSTALLATION_PNPM]: #pnpm-
[INSTALLATION_BUN]: #bun-
[INSTALLATION_DENO]: https://deno.land/manual@v1.36.4/examples/manage_dependencies
[VERSION_BADGE]: https://img.shields.io/npm/v/@wonize/tsconfig?color=00273F&label=VERSION&style=flat-square
[LICENSE_BADGE]: https://img.shields.io/npm/l/@wonize/tsconfig?color=00273F&label=LICENSE&style=flat-square
